@@ -19,10 +19,11 @@ Adapted from WWW::Pastebin::PastebinCom::Create module.
 
 =head1 VERSION
 
-version 1.0002
+version 1.0006
 
 =head1 EXAMPLE USAGE
-		pastebin-create --text 'TEXT' --format 'none' --expiry 10m --private 0 --desc 'A TITLE'
+	
+	pastebin-create --text 'TEXT' --format 'none' --expiry 10m --private 0 --desc 'A TITLE'
 
 =head1 OPTIONS
 
@@ -57,7 +58,7 @@ Your paste title description.
 
 =head1 SEE ALSO
 
-L<https://metacpan.org/pod/WWW::Pastebin::PastebinCom::Create", L< https://metacpan.org/pod/App::Nopaste">
+L<https://metacpan.org/pod/WWW::Pastebin::PastebinCom::Create">, L< https://metacpan.org/pod/App::Nopaste">
 
 
 =head1 AUTHOR
